@@ -1,4 +1,4 @@
-# --------------------------------------------------------------- Imports ---------------------------------------------------------------- #
+# ------------------------------------------------------------ Imports ----------------------------------------------------------- #
 
 # System
 from typing import List, Dict, Optional, Tuple, Callable, Union
@@ -6,7 +6,8 @@ import time, json
 from sys import platform
 
 # Pip
-from selenium_uploader_account import SeleniumUploaderAccount, Proxy, BaseAddonInstallSettings
+from selenium_uploader_account import SeleniumUploaderAccount
+from selenium_browser import Browser
 from noraise import noraise
 from kcu import strings
 from kstopit import signal_timeoutable
@@ -23,11 +24,11 @@ from .enums.upload_status import UploadStatus
 from .enums.analytics_period import AnalyticsPeriod
 from .enums.analytics_tab import AnalyticsTab
 
-# ---------------------------------------------------------------------------------------------------------------------------------------- #
+# -------------------------------------------------------------------------------------------------------------------------------- #
 
 
 
-# --------------------------------------------------------------- Defines ---------------------------------------------------------------- #
+# ------------------------------------------------------------ Defines ----------------------------------------------------------- #
 
 YT_URL                  = 'https://www.youtube.com'
 YT_STUDIO_URL           = 'https://studio.youtube.com'
@@ -46,56 +47,21 @@ MAX_TAG_CHAR_LEN            = 30
 
 LOGIN_INFO_COOKIE_NAME = 'LOGIN_INFO'
 
-# ---------------------------------------------------------------------------------------------------------------------------------------- #
+# -------------------------------------------------------------------------------------------------------------------------------- #
 
 
 
-# ----------------------------------------------------------- class: Youtube ------------------------------------------------------------- #
+# -------------------------------------------------------- class: Youtube -------------------------------------------------------- #
 
 class Youtube(SeleniumUploaderAccount):
 
-    # ------------------------------------------------------------- Init ------------------------------------------------------------- #
+    # --------------------------------------------------------- Init --------------------------------------------------------- #
 
     def __init__(
         self,
 
-        # cookies
-        cookies_folder_path: Optional[str] = None,
-        cookies_id: Optional[str] = None,
-        pickle_cookies: bool = False,
-
-        # proxy
-        proxy: Optional[Union[Proxy, str]] = None,
-        # proxy - legacy (kept for convenience)
-        host: Optional[str] = None,
-        port: Optional[int] = None,
-
-        # addons
-        addons_folder_path: Optional[str] = None,
-        addon_settings: Optional[List[BaseAddonInstallSettings]] = None,
-        # addons - legacy (kept for convenience)
-        extensions_folder_path: Optional[str] = None,
-
-        # other paths
-        geckodriver_path: Optional[str] = None,
-        firefox_binary_path: Optional[str] = None,
-        profile_path: Optional[str] = None,
-
-        # profile settings
-        private: bool = False,
-        full_screen: bool = True,
-        language: str = 'en-us',
-        user_agent: Optional[str] = None,
-        disable_images: bool = False,
-
-        # option settings
-        screen_size: Optional[Tuple[int, int]] = None, # (width, height)
-        headless: bool = False,
-        mute_audio: bool = False,
-        home_page_url: Optional[str] = None,
-
-        # find function
-        default_find_func_timeout: int = 2.5,
+        # browser
+        browser: Browser,
 
         # login
         prompt_user_input_login: bool = True,
@@ -103,43 +69,8 @@ class Youtube(SeleniumUploaderAccount):
         login_prompt_timeout_seconds: int = 60*5
     ):
         super().__init__(
-            # cookies
-            cookies_folder_path=cookies_folder_path,
-            cookies_id=cookies_id,
-            pickle_cookies=pickle_cookies,
-
-            # proxy
-            proxy=proxy,
-            # proxy - legacy (kept for convenience)
-            host=host,
-            port=port,
-
-            # addons
-            addons_folder_path=addons_folder_path,
-            addon_settings=addon_settings,
-            # addons - legacy (kept for convenience)
-            extensions_folder_path=extensions_folder_path,
-
-            # other paths
-            geckodriver_path=geckodriver_path,
-            firefox_binary_path=firefox_binary_path,
-            profile_path=profile_path,
-
-            # profile settings
-            private=private,
-            full_screen=full_screen,
-            language=language,
-            user_agent=user_agent,
-            disable_images=disable_images,
-
-            # option settings
-            screen_size=screen_size,
-            headless=headless,
-            mute_audio=mute_audio,
-            home_page_url=home_page_url,
-
-            # find function
-            default_find_func_timeout=default_find_func_timeout,
+            # browser
+            browser=browser,
 
             # login
             prompt_user_input_login=prompt_user_input_login,
@@ -151,7 +82,7 @@ class Youtube(SeleniumUploaderAccount):
             self.__dismiss_alerts()
 
 
-    # ---------------------------------------------------------- Overrides ----------------------------------------------------------- #
+    # ------------------------------------------------------- Overrides ------------------------------------------------------ #
 
     def _upload_function(self) -> Callable:
         return self.upload
@@ -169,7 +100,7 @@ class Youtube(SeleniumUploaderAccount):
         return LOGIN_INFO_COOKIE_NAME
 
 
-    # -------------------------------------------------------- Public methods -------------------------------------------------------- #
+    # ---------------------------------------------------- Public methods ---------------------------------------------------- #
 
     def get_sub_and_video_count(self, channel_id: str) -> Optional[Tuple[int, int]]:
         return YoutubeScraper(user_agent=self.user_agent, proxy=self.proxy.string).get_sub_and_video_count(channel_id=channel_id)
@@ -498,68 +429,8 @@ class Youtube(SeleniumUploaderAccount):
 
         return self.__dismiss_welcome_popup(offset=offset, timeout=timeout)
 
-    @noraise()
-    def bulk_set_videos_to_private(
-        self
-    ) -> None:
-        channel_id = self._get_current_user_id()
-        self.get(YT_PROFILE_CONTENT_URL.format(channel_id))
-        time.sleep(2)
-        self.browser.find_by('input', class_='text-input style-scope ytcp-chip-bar').click()
-        time.sleep(0.5)
-        self.browser.find_by('paper-item', id='text-item-6').click()
-        time.sleep(0.5)
-        self.browser.find_by('ytcp-checkbox-lit', {'test-id':'PUBLIC'}).click()
-        time.sleep(0.5)
-        self.browser.find_by('ytcp-button', id='apply-button').click()
-        time.sleep(0.5)
-        next_page_button = self.browser.find_by('ytcp-icon-button', id='navigate-after')
-        next_page_status = next_page_button.get_attribute('aria-disabled')
 
-        while next_page_status=='false':
-            self.__change_to_private_on_current_page()
-
-            next_page_button = self.browser.find_by('ytcp-icon-button', id='navigate-after', timeout=5)
-            next_page_status = next_page_button.get_attribute('aria-disabled')
-            print('aria-disabled is', next_page_status, type(next_page_status))
-            next_page_button.click()
-            time.sleep(2.5)
-
-            if next_page_status is None or next_page_status is 'false':
-                return
-
-        self.quit()
-
-        return
-
-    def __change_to_private_on_current_page(
-        self
-    ) -> None:
-        try:
-            self.browser.find_by('ytcp-checkbox-lit', id='selection-checkbox').click()
-            time.sleep(0.5)
-            edit_container = self.browser.find_by('ytcp-select', class_='top-dropdown bulk-actions-edit style-scope ytcp-bulk-actions', timeout=180)
-            self.browser.find_by('ytcp-dropdown-trigger', class_='style-scope ytcp-text-dropdown-trigger', in_element=edit_container).click()
-            time.sleep(0.5)
-            self.browser.find_by('paper-item', {'test-id':'VISIBILITY'}).click()
-            time.sleep(0.5)
-            self.browser.find_by('ytcp-form-select', class_='style-scope ytcp-bulk-actions-editor-visibility').click()
-            time.sleep(0.5)
-            self.browser.find_by('paper-item', {'test-id':'PRIVATE'}).click()
-            time.sleep(0.5)
-            self.browser.find_by('ytcp-button', id='submit-button').click()
-            time.sleep(0.5)
-            self.browser.find_by('ytcp-checkbox-lit', id='confirm-checkbox').click()
-            time.sleep(0.5)
-            self.browser.find_by('ytcp-button', id='confirm-button', class_='style-scope ytcp-confirmation-dialog').click()
-            time.sleep(2.5)
-        except Exception as e:
-            print(e)
-
-        return
-
-
-    # ------------------------------------------------------- Private methods -------------------------------------------------------- #
+    # ---------------------------------------------------- Private methods --------------------------------------------------- #
 
     @signal_timeoutable(name='Upload')
     def __upload(
@@ -593,6 +464,7 @@ class Youtube(SeleniumUploaderAccount):
 
             title_field = self.browser.find_by('div', id_='textbox', timeout=5) or self.browser.find_by(id_='textbox', timeout=5)
             time.sleep(0.5)
+            title_field.clear()
             title_field.send_keys(Keys.BACK_SPACE)
 
             try:
@@ -603,15 +475,15 @@ class Youtube(SeleniumUploaderAccount):
             except Exception as e:
                 self.print(e)
 
-            # time.sleep(0.5)
-            # title_field.send_keys('a')
-            # time.sleep(0.5)
-            # title_field.send_keys(Keys.BACK_SPACE)
+            time.sleep(0.5)
+            title_field.send_keys('a')
+            time.sleep(0.5)
+            title_field.send_keys(Keys.BACK_SPACE)
 
             time.sleep(0.5)
             title_field.send_keys(title[:MAX_TITLE_CHAR_LEN])
             self.print('Upload: added title')
-            description_container = self.browser.find_by('ytcp-mention-textbox', class_='description-textarea style-scope ytcp-uploads-basics') or self.browser.find(By.XPATH, "/html/body/ytcp-uploads-dialog/paper-dialog/div/ytcp-animatable[1]/ytcp-uploads-details/div/ytcp-uploads-basics/ytcp-mention-textbox[2]")
+            description_container = self.browser.find_by('ytcp-mention-textbox', class_='description-textarea style-scope ytcp-uploads-basics') or self.browser.find_by('div', id='description-container')
             description_field = self.browser.find_by(id='textbox', in_element=description_container)
             description_field.click()
             time.sleep(0.5)
@@ -628,7 +500,7 @@ class Youtube(SeleniumUploaderAccount):
                 except Exception as e:
                     self.print('Upload: Thumbnail error: ', e)
 
-            (self.browser.find_by('ytcp-button', class_='advanced-button style-scope ytcp-uploads-details') or self.browser.find(By.XPATH, "/html/body/ytcp-uploads-dialog/paper-dialog/div/ytcp-animatable[1]/ytcp-uploads-details/div/div/ytcp-button/div")).click()
+            (self.browser.find_by('ytcp-button', class_='advanced-button style-scope ytcp-uploads-details') or self.browser.find_by('ytcp-button', {"id":"toggle-button", "class":"style-scope ytcp-video-metadata-editor", "role":"button"})).click()
 
             self.print("Upload: clicked more options")
 
@@ -638,7 +510,7 @@ class Youtube(SeleniumUploaderAccount):
                 tags_field.send_keys(','.join([t for t in tags if len(t) <= MAX_TAG_CHAR_LEN])[:MAX_TAGS_CHAR_LEN-1] + ',')
                 self.print("Upload: added tags")
 
-            kids_selection_name = 'MADE_FOR_KIDS' if made_for_kids else 'NOT_MADE_FOR_KIDS'
+            kids_selection_name = 'VIDEO_MADE_FOR_KIDS_MFK' if made_for_kids else 'VIDEO_MADE_FOR_KIDS_NOT_MFK'
             kids_section = self.browser.find(By.NAME, kids_selection_name)
             self.browser.find(By.ID, 'radioLabel', kids_section).click()
             self.print('Upload: did set', kids_selection_name)
@@ -649,9 +521,10 @@ class Youtube(SeleniumUploaderAccount):
             self.browser.find(By.ID, 'next-button').click()
             self.print('Upload: clicked second next')
 
-            third_next = self.browser.find_by('ytcp-button', id='next-button')
+            visibility_tab = self.browser.find_by('button', {'test-id':'REVIEW', 'state':'active'})
 
-            if third_next:
+            if not visibility_tab:
+                third_next = self.browser.find_by('ytcp-button', id='next-button')
                 third_next.click()
                 self.print('Upload: clicked third next')
 
@@ -899,4 +772,4 @@ class Youtube(SeleniumUploaderAccount):
         return YT_URL + '/channel/' + channel_id + '/videos?view=0&sort=da&flow=grid'
 
 
-# ---------------------------------------------------------------------------------------------------------------------------------------- #
\ No newline at end of file
+# -------------------------------------------------------------------------------------------------------------------------------- #
\ No newline at end of file
